@@ -1,8 +1,5 @@
 package PerlIO::Layers;
-{
-  $PerlIO::Layers::VERSION = '0.010';
-}
-
+$PerlIO::Layers::VERSION = '0.011';
 use 5.008_001;
 use strict;
 use warnings FATAL => 'all';
@@ -10,7 +7,6 @@ use XSLoader;
 use PerlIO ();
 use Carp qw/croak/;
 use List::Util qw/reduce max/;
-use List::MoreUtils qw/natatime/;
 use Exporter 5.57 qw/import/;
 
 our @EXPORT_OK = qw/query_handle get_layers get_buffer_sizes/;
@@ -31,8 +27,8 @@ sub _has_flags {
 	my $check_flag = _names_to_flags(@_);
 	return sub {
 		my ($fh, $layer) = @_;
-		my $iterator = natatime(3, PerlIO::get_layers($fh, details => 1));
-		while (my ($name, $arguments, $flags) = $iterator->()) {
+		my @info = PerlIO::get_layers($fh, details => 1);
+		while (my ($name, $arguments, $flags) = splice @info, 0, 3) {
 			next if defined $layer and $name ne $layer;
 			my $entry = $flags & $check_flag;
 			return 1 if $entry;
@@ -71,8 +67,8 @@ my %layer_query_for = (
 	utf8      => _has_flags('UTF8'),
 	binary    => sub {
 		my ($fh, $layer) = @_;
-		my $iterator = natatime(3, PerlIO::get_layers($fh, details => 1));
-		while (my ($name, $arguments, $flags) = $iterator->()) {
+		my @info = PerlIO::get_layers($fh, details => 1);
+		while (my ($name, $arguments, $flags) = splice @info, 0, 3) {
 			next if defined $layer and $name ne $layer;
 			return 0 if not $is_binary{$name} or $flags & $nonbinary_flags;
 		}
@@ -80,8 +76,8 @@ my %layer_query_for = (
 	},
 	mappable  => sub {
 		my ($fh, $layer) = @_;
-		my $iterator = natatime(3, PerlIO::get_layers($fh, details => 1));
-		while (my ($name, $arguments, $flags) = $iterator->()) {
+		my @info = PerlIO::get_layers($fh, details => 1);
+		while (my ($name, $arguments, $flags) = splice @info, 0, 3) {
 			next if defined $layer and $name ne $layer;
 			return 0 if not $is_binary{$name} or $flags & $crlf_flags;
 		}
@@ -89,8 +85,8 @@ my %layer_query_for = (
 	},
 	layer     => sub {
 		my ($fh, $layer) = @_;
-		my $iterator = natatime(3, PerlIO::get_layers($fh, details => 1));
-		while (my ($name, $arguments, $flags) = $iterator->()) {
+		my @info = PerlIO::get_layers($fh, details => 1);
+		while (my ($name, $arguments, $flags) = splice @info, 0, 3) {
 			return 1 if $name eq $layer;
 		}
 		return 0;
@@ -114,8 +110,8 @@ sub query_handle {
 sub get_layers {
 	my $fh = shift;
 	my @results;
-	my $iterator = natatime(3, PerlIO::get_layers($fh, details => 1));
-	while (my ($name, $arguments, $flags) = $iterator->()) {
+	my @info = PerlIO::get_layers($fh, details => 1);
+	while (my ($name, $arguments, $flags) = splice @info, 0, 3) {
 		push @results, [ $name, $arguments, [ _flag_names($flags) ] ];
 	}
 	return @results;
@@ -125,17 +121,19 @@ sub get_layers {
 
 # ABSTRACT: Querying your filehandle's capabilities
 
-
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 PerlIO::Layers - Querying your filehandle's capabilities
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 SYNOPSIS
 
@@ -217,7 +215,73 @@ Check whether the buffer size is equal to C<$argument>.
 
 =head2 get_layers($fh)
 
-Gets information on the layers of a filehandle. It's a list with whose entries have 3 elements: the name of the layer, the arguments of the layer (may be undef) and an arrayref with the flags of the layer as strings. The flags array can contain any of these values. You probably want to use query_layers instead. C<query_handle> provides a more high level interface to this, you should probably use that when you can.
+Gets information on the layers of a filehandle. It's a list with whose entries have 3 elements: the name of the layer, the arguments of the layer (may be undef) and an arrayref with the flags of the layer as strings. The flags array can contain any of these values:
+
+=over 4
+
+=item * EOF
+
+End of file has been reached.
+
+=item * CANWRITE
+
+Writes are permitted, i.e. opened as ">" or "+<" or ">>", etc.
+
+=item * CANREAD
+
+Reads are permitted i.e. opened "<" or "+>".
+
+=item * ERROR
+
+An error has occurred.
+
+=item * TRUNCATE
+
+Truncate file suggested by open mode.
+
+=item * APPEND
+
+All writes should be appends.
+
+=item * CRLF
+
+Layer is performing Win32-like "\n" mapped to CR,LF for output and CR,LF mapped to "\n" for input. Normally the provided "crlf" layer is the only layer that need bother about this. C<binmode> will mess with this flag rather than add/remove layers if the PERLIO_K_CANCRLF bit is set for the layers class.
+
+=item * UTF8
+
+Data written to this layer should be UTF-8 encoded; data provided by this layer should be considered UTF-8 encoded. Can be set on any layer by ":utf8" dummy layer. Also set on ":encoding" layer.
+
+=item * UNBUF
+
+Layer is unbuffered - i.e. write to next layer down should occur for each write to this layer.
+
+=item * WRBUF
+
+The buffer for this layer currently holds data written to it but not sent to next layer.
+
+=item * RDBUF
+
+The buffer for this layer currently holds unconsumed data read from layer below.
+
+=item * LINEBUF
+
+Layer is line buffered. Write data should be passed to next layer down whenever a "\n" is seen. Any data beyond the "\n" should then be processed.
+
+=item * TEMP
+
+File has been unlink()ed, or should be deleted on close().
+
+=item * OPEN
+
+Handle is open.
+
+=item * FASTGETS
+
+This instance of this layer supports the "fast gets" interface. Normally set based on PERLIO_K_FASTGETS for the class and by the existence of the function(s) in the table. However a class that normally provides that interface may need to avoid it on a particular instance. The "pending" layer needs to do this when it is pushed above a layer which does not support the interface.
+
+=back
+
+C<query_handle> provides a more high level interface to this, you should probably use that when you can.
 
 =head2 get_buffer_sizes($fh)
 
@@ -235,8 +299,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
